[−][src]Enum valid::constraint::CharCount
The number of characters must be within some bounds.
The validation function can be applied in the
FieldName context.
It is implemented for all types T that implement the
HasCharCount property trait.
Variants
Max(u32)The number of characters must be less than or equal to the specified maximum
Min(u32)The number of characters must be greater than or equal to the specified minimum
MinMax(u32, u32)The number of characters must be between the specified minimum and maximum (inclusive)
Exact(u32)The number of characters must be equal to the specified amount