pub enum Length {
Max(usize),
Min(usize),
MinMax(usize, usize),
Exact(usize),
}Expand description
Variants
Max(usize)
The length of the value must be less than or equal to the specified maximum
Min(usize)
The length of the value must be greater than or equal to the specified minimum
MinMax(usize, usize)
The length of the value must be between the specified minimum and maximum (inclusive)
Exact(usize)
The value must be of an exact length